@@ -4,6 +4,7 @@
 # or https://github.com/scikit-hep/vector for details.
 
 import typing
+from contextlib import suppress
 
 from vector._typeutils import (
     BoolCollection,
@@ -170,9 +171,7 @@ class VectorProtocol:
     GenericClass: typing.Type["VectorProtocol"]
 
     def to_Vector2D(self) -> "VectorProtocolPlanar":
-        """
-        Projects this vector/these vectors onto azimuthal coordinates only.
-        """
+        """Projects this vector/these vectors onto azimuthal coordinates only."""
         raise AssertionError
 
     def to_Vector3D(self) -> "VectorProtocolSpatial":
@@ -382,7 +381,7 @@ class VectorProtocol:
 
         This method is equivalent to the ``==`` operator.
 
-        Typically, you'll want to check :doc:`vector._methods.VectorProtocol.isclose`
+        Typically, you'll want to check :meth:`vector._methods.VectorProtocol.isclose`
         to allow for numerical errors.
         """
         raise AssertionError
@@ -394,7 +393,7 @@ class VectorProtocol:
 
         This method is equivalent to the ``!=`` operator.
 
-        Typically, you'll want to check :doc:`vector._methods.VectorProtocol.isclose`
+        Typically, you'll want to check :meth:`vector._methods.VectorProtocol.isclose`
         to allow for numerical errors.
         """
         raise AssertionError
@@ -431,16 +430,12 @@ class VectorProtocolPlanar(VectorProtocol):
 
     @property
     def x(self) -> ScalarCollection:
-        """
-        The Cartesian $x$ coordinate of the vector or every vector in the array.
-        """
+        """The Cartesian $x$ coordinate of the vector or every vector in the array."""
         raise AssertionError
 
     @property
     def y(self) -> ScalarCollection:
-        """
-        The Cartesian $y$ coordinate of the vector or every vector in the array.
-        """
+        """The Cartesian $y$ coordinate of the vector or every vector in the array."""
         raise AssertionError
 
     @property
@@ -455,9 +450,7 @@ class VectorProtocolPlanar(VectorProtocol):
 
     @property
     def rho2(self) -> ScalarCollection:
-        r"""
-        The polar $\rho$ coordinate squared of the vector or every vector in the array.
-        """
+        r"""The polar $\rho$ coordinate squared of the vector or every vector in the array."""
         raise AssertionError
 
     @property
@@ -468,10 +461,23 @@ class VectorProtocolPlanar(VectorProtocol):
         """
         raise AssertionError
 
-    def deltaphi(self, other: VectorProtocol) -> ScalarCollection:
-        r"""
-        Signed difference in $\phi$ of ``self`` minus ``other`` (in radians).
+    def scale2D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
         """
+        Returns vector(s) with the 2D part scaled by a ``factor``, not affecting
+        any longitudinal or temporal parts.
+        """
+        raise AssertionError
+
+    @property
+    def neg2D(self: SameVectorType) -> SameVectorType:
+        """
+        Returns vector(s) with the 2D part negated, not affecting any longitudinal
+        or temporal parts.
+        """
+        raise AssertionError
+
+    def deltaphi(self, other: VectorProtocol) -> ScalarCollection:
+        r"""Signed difference in $\phi$ of ``self`` minus ``other`` (in radians)."""
         raise AssertionError
 
     def rotateZ(self: SameVectorType, angle: ScalarCollection) -> SameVectorType:
@@ -507,7 +513,7 @@ class VectorProtocolPlanar(VectorProtocol):
         (i.e. not "antiparallel"; dot product is nearly ``abs(self) * abs(other)``).
 
         The ``tolerance`` is measured in units of $\cos(\Delta\alpha)$ where $\Delta\alpha$
-        is ``self.deltaangle(other)`.
+        is ``self.deltaangle(other)``.
         """
         raise AssertionError
 
@@ -519,7 +525,7 @@ class VectorProtocolPlanar(VectorProtocol):
         (i.e. dot product is nearly ``-abs(self) * abs(other)``).
 
         The ``tolerance`` is measured in units of $\cos(\Delta\alpha)$ where $\Delta\alpha$
-        is ``self.deltaangle(other)`.
+        is ``self.deltaangle(other)``.
         """
         raise AssertionError
 
@@ -531,7 +537,7 @@ class VectorProtocolPlanar(VectorProtocol):
         (i.e. dot product is nearly ``0``).
 
         The ``tolerance`` is measured in units of $\cos(\Delta\alpha)$ where $\Delta\alpha$
-        is ``self.deltaangle(other)`.
+        is ``self.deltaangle(other)``.
         """
         raise AssertionError
 
@@ -547,9 +553,7 @@ class VectorProtocolSpatial(VectorProtocolPlanar):
 
     @property
     def z(self) -> ScalarCollection:
-        """
-        The Cartesian $z$ coordinate of the vector or every vector in the array.
-        """
+        """The Cartesian $z$ coordinate of the vector or every vector in the array."""
         raise AssertionError
 
     @property
@@ -586,15 +590,26 @@ class VectorProtocolSpatial(VectorProtocolPlanar):
 
     @property
     def mag(self) -> ScalarCollection:
-        """
-        The magnitude of the vector(s) in 3D (not including any temporal parts).
-        """
+        """The magnitude of the vector(s) in 3D (not including any temporal parts)."""
         raise AssertionError
 
     @property
     def mag2(self) -> ScalarCollection:
+        """The magnitude-squared of the vector(s) in 3D (not including any temporal parts)."""
+        raise AssertionError
+
+    def scale3D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
         """
-        The magnitude-squared of the vector(s) in 3D (not including any temporal parts).
+        Returns vector(s) with the 3D part scaled by a ``factor``, not affecting
+        any longitudinal or temporal parts.
+        """
+        raise AssertionError
+
+    @property
+    def neg3D(self: SameVectorType) -> SameVectorType:
+        """
+        Returns vector(s) with the 3D part negated, not affecting any longitudinal
+        or temporal parts.
         """
         raise AssertionError
 
@@ -614,15 +629,13 @@ class VectorProtocolSpatial(VectorProtocolPlanar):
         raise AssertionError
 
     def deltaeta(self, other: "VectorProtocol") -> ScalarCollection:
-        r"""
-        Signed difference in $\eta$ of ``self`` minus ``other``.
-        """
+        r"""Signed difference in $\eta$ of ``self`` minus ``other``."""
         raise AssertionError
 
     def deltaR(self, other: "VectorProtocol") -> ScalarCollection:
         r"""
-        Sum in quadrature of :doc:`vector._methods.VectorProtocolPlanar.deltaphi`
-        and :doc:`vector._methods.VectorProtocolPlanar.deltaeta`:
+        Sum in quadrature of :meth:`vector._methods.VectorProtocolPlanar.deltaphi`
+        and :meth:`vector._methods.VectorProtocolSpatial.deltaeta`:
 
         $$\Delta R = \sqrt{\Delta\phi^2 + \Delta\eta^2}$$
         """
@@ -631,8 +644,8 @@ class VectorProtocolSpatial(VectorProtocolPlanar):
     def deltaR2(self, other: "VectorProtocol") -> ScalarCollection:
         r"""
         Square of the sum in quadrature of
-        :doc:`vector._methods.VectorProtocolPlanar.deltaphi` and
-        :doc:`vector._methods.VectorProtocolSpatial.deltaeta`:
+        :meth:`vector._methods.VectorProtocolPlanar.deltaphi` and
+        :meth:`vector._methods.VectorProtocolSpatial.deltaeta`:
 
         $$\Delta R^2 = \Delta\phi^2 + \Delta\eta^2$$
         """
@@ -687,7 +700,7 @@ class VectorProtocolSpatial(VectorProtocolPlanar):
           are proper Euler angles
         - ``"zxz"``, ``"xyx"``, ``"yzy"``, ``"zyz"``, ``"xzx"``, and ``"yxy"``
           are Tait-Bryan angles (see
-          :doc:`vector._methods.VectorProtocolSpatial.rotate_nautical`)
+          :meth:`vector._methods.VectorProtocolSpatial.rotate_nautical`)
 
         The names ``phi``, ``theta``, and ``psi`` agree with
         `Wikipedia's terminology <https://en.wikipedia.org/wiki/Euler_angles>`_,
@@ -709,8 +722,8 @@ class VectorProtocolSpatial(VectorProtocolPlanar):
         """
         Rotates the vector(s) by three given angles: ``yaw``, ``pitch``, and ``roll``
         (in radians). These are Tait-Bryan angles often used for boats and planes
-        (see `this lesson <http://planning.cs.uiuc.edu/node102.html>`_ and
-        `this lesson <http://www.chrobotics.com/library/understanding-euler-angles>`_).
+        (see `this lesson <http://planning.cs.uiuc.edu/node102.html>`__ and
+        `this lesson <http://www.chrobotics.com/library/understanding-euler-angles>`__).
 
         This function is entirely equivalent to
 
@@ -866,6 +879,35 @@ class VectorProtocolLorentz(VectorProtocolSpatial):
         """
         raise AssertionError
 
+    def deltaRapidityPhi(self, other: "VectorProtocol") -> ScalarCollection:
+        r"""
+        Sum in quadrature of :meth:`vector._methods.VectorProtocolPlanar.deltaphi`
+        and the difference in :attr:`vector._methods.VectorProtocolLorentz.rapidity`
+        of the two vectors:
+
+        $$\Delta R_{\mbox{rapidity}} = \sqrt{\Delta\phi^2 + \Delta \mbox{rapidity}^2}$$
+        """
+        raise AssertionError
+
+    def deltaRapidityPhi2(self, other: "VectorProtocol") -> ScalarCollection:
+        r"""
+        Square of the sum in quadrature of
+        :meth:`vector._methods.VectorProtocolPlanar.deltaphi` and the difference in
+        :attr:`vector._methods.VectorProtocolLorentz.rapidity` of the two vectors:
+
+        $$\Delta R_{\mbox{rapidity}} = \Delta\phi^2 + \Delta \mbox{rapidity}^2$$
+        """
+        raise AssertionError
+
+    def scale4D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
+        """Same as ``scale``."""
+        raise AssertionError
+
+    @property
+    def neg4D(self: SameVectorType) -> SameVectorType:
+        """Same as multiplying by -1."""
+        raise AssertionError
+
     def boost_p4(self: SameVectorType, p4: "VectorProtocolLorentz") -> SameVectorType:
         """
         Boosts the vector or array of vectors in a direction and magnitude given
@@ -875,11 +917,20 @@ class VectorProtocolLorentz(VectorProtocolSpatial):
 
         .. code-block:: python
 
-            boost_beta3(p4.to_beta3)
+            boost_beta3(p4.to_beta3())
 
-        where :doc:`vector._methods.VectorProtocolLorentz.to_beta3` converts a
+        where :meth:`vector._methods.VectorProtocolLorentz.to_beta3` converts a
         4D Lorentz vector into a 3D velocity (in which lightlike velocities have
         ``mag == 1``).
+
+        Note that ``v.boost_p4(v)`` does not boost into the center-of-mass (CM) frame
+        of ``v``; it boosts *away* from its CM frame. Neither does ``v.boost_p4(-v)``,
+        since that negates the time component of ``v`` as well.
+
+        To boost to the center-of-mass frame of a vector ``v``, use
+        :meth:`vector._methods.VectorProtocolLorentz.boostCM_of_p4`. For instance,
+        ``v.boostCM_of_p4(v)`` is guaranteed to have spatial components close to zero
+        and a temporal component close to ``v.tau``.
         """
         raise AssertionError
 
@@ -889,6 +940,16 @@ class VectorProtocolLorentz(VectorProtocolSpatial):
         """
         Boosts the vector or array of vectors in a direction and magnitude given
         by the 3D velocity or array of velocity vectors ``beta3``.
+
+        Note that ``v.boost_beta3(v.to_beta3())`` does not boost into the center-of-mass (CM) frame
+        of ``v``; it boosts *away* from its CM frame. Neither does ``v.boost_beta3((-v).to_beta3())``,
+        since that negates the time component of ``v`` as well. On the other hand,
+        ``v.boost_beta3(-(v.to_beta3()))`` *would* boost to the center-of-mass frame.
+
+        However, there's a function for that: :meth:`vector._methods.VectorProtocolLorentz.boostCM_of_beta3`
+        is explicit about boosting to a center-of-mass (CM) frame and it handles the
+        negative sign for you: ``v.boostCM_of_beta3(v.to_beta3())`` is guaranteed to
+        have spatial components close to zero and a temporal component close to ``v.tau``.
         """
         raise AssertionError
 
@@ -897,11 +958,67 @@ class VectorProtocolLorentz(VectorProtocolSpatial):
         Boosts the vector or array of vectors using the 3D or 4D ``booster``.
 
         If ``booster`` is 3D, it is interpreted as a velocity (in which lightlike
-        velocities have ``mag == 1``) and :doc:`vector._methods.VectorProtocolLorentz.boost_beta3`
+        velocities have ``mag == 1``) and :meth:`vector._methods.VectorProtocolLorentz.boost_beta3`
         is called.
 
         If ``booster`` is 4D, it is interpreted as a Lorentz vector and
-        :doc:`vector._methods.VectorProtocolLorentz.boost_p4` is called.
+        :meth:`vector._methods.VectorProtocolLorentz.boost_p4` is called.
+
+        Note that ``v.boost(v)`` does not boost into the center-of-mass (CM) frame
+        of ``v``; it boosts *away* from its CM frame. Neither does ``v.boost(-v)``,
+        since that negates the time component of ``v`` as well.
+
+        To boost to the center-of-mass frame of a vector ``v``, use
+        :meth:`vector._methods.VectorProtocolLorentz.boostCM_of`. For instance,
+        ``v.boostCM_of(v)`` is guaranteed to have spatial components close to zero
+        and a temporal component close to ``v.tau``.
+        """
+        raise AssertionError
+
+    def boostCM_of_p4(
+        self: SameVectorType, p4: "VectorProtocolLorentz"
+    ) -> SameVectorType:
+        """
+        Boosts the vector or array of vectors to the center-of-mass (CM) frame of
+        the 4D vector or array of vectors ``p4``.
+
+        This function is equivalent to but more numerically stable than
+
+        .. code-block:: python
+
+            boostCM_of_beta3(p4.to_beta3())
+
+        Note that ``v.boostCM_of_p4(v)`` is guaranteed to have spatial components close
+        to zero and a temporal component close to ``v.tau``.
+        """
+        raise AssertionError
+
+    def boostCM_of_beta3(
+        self: SameVectorType, beta3: "VectorProtocolSpatial"
+    ) -> SameVectorType:
+        """
+        Boosts the vector or array of vectors to the center-of-mass (CM) frame of
+        the 3D velocity or array of velocity vectors ``beta3``.
+
+        Note that ``v.boostCM_of_beta3(v.to_beta3())`` is guaranteed to have spatial
+        components close to zero and a temporal component close to ``v.tau``.
+        """
+        raise AssertionError
+
+    def boostCM_of(self: SameVectorType, booster: "VectorProtocol") -> SameVectorType:
+        """
+        Boosts the vector or array of vectors to the center-of-mass (CM) frame of
+        the 3D or 4D ``booster``.
+
+        If ``booster`` is 3D, it is interpreted as a velocity (in which lightlike
+        velocities have ``mag == 1``) and :meth:`vector._methods.VectorProtocolLorentz.boostCM_of_beta3`
+        is called.
+
+        If ``booster`` is 4D, it is interpreted as a Lorentz vector and
+        :meth:`vector._methods.VectorProtocolLorentz.boostCM_of_p4` is called.
+
+        Note that ``v.boostCM_of(v)`` is guaranteed to have spatial components close
+        to zero and a temporal component close to ``v.tau``.
         """
         raise AssertionError
 
@@ -987,11 +1104,11 @@ class VectorProtocolLorentz(VectorProtocolSpatial):
 
         The ``tolerance`` is in units of ``t`` and ``mag``. Note that
 
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_timelike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_timelike`
           is ``0``
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_spacelike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_spacelike`
           is ``0``
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_lightlike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_lightlike`
           is ``1e-5``
 
         If you want to use these methods to divide space-time into non-overlapping
@@ -1006,11 +1123,11 @@ class VectorProtocolLorentz(VectorProtocolSpatial):
 
         The ``tolerance`` is in units of ``t`` and ``mag``. Note that
 
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_timelike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_timelike`
           is ``0``
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_spacelike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_spacelike`
           is ``0``
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_lightlike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_lightlike`
           is ``1e-5``
 
         If you want to use these methods to divide space-time into non-overlapping
@@ -1025,11 +1142,11 @@ class VectorProtocolLorentz(VectorProtocolSpatial):
 
         The ``tolerance`` is in units of ``t`` and ``mag``. Note that
 
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_timelike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_timelike`
           is ``0``
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_spacelike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_spacelike`
           is ``0``
-        - the default ``tolerance`` for :doc:`vector._methods.VectorProtocolLorentz.is_lightlike`
+        - the default ``tolerance`` for :meth:`vector._methods.VectorProtocolLorentz.is_lightlike`
           is ``1e-5``
 
         If you want to use these methods to divide space-time into non-overlapping
@@ -1041,146 +1158,106 @@ class VectorProtocolLorentz(VectorProtocolSpatial):
 class MomentumProtocolPlanar(VectorProtocolPlanar):
     @property
     def px(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolPlanar.x`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolPlanar.x`."""
         raise AssertionError
 
     @property
     def py(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolPlanar.y`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolPlanar.y`."""
         raise AssertionError
 
     @property
     def pt(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolPlanar.rho`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolPlanar.rho`."""
         raise AssertionError
 
     @property
     def pt2(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolPlanar.rho2`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolPlanar.rho2`."""
         raise AssertionError
 
 
 class MomentumProtocolSpatial(VectorProtocolSpatial, MomentumProtocolPlanar):
     @property
     def pz(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolSpatial.z`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolSpatial.z`."""
         raise AssertionError
 
     @property
     def pseudorapidity(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolSpatial.eta`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolSpatial.eta`."""
         raise AssertionError
 
     @property
     def p(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolSpatial.mag`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolSpatial.mag`."""
         raise AssertionError
 
     @property
     def p2(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolSpatial.mag2`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolSpatial.mag2`."""
         raise AssertionError
 
 
 class MomentumProtocolLorentz(VectorProtocolLorentz, MomentumProtocolSpatial):
     @property
     def E(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.t`.
-        """
+        """Momentum-synonyor :attr:`vector._methods.VectorProtocolLorentz.t`."""
         raise AssertionError
 
     @property
     def e(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.t`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.t`."""
         raise AssertionError
 
     @property
     def energy(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.t`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.t`."""
         raise AssertionError
 
     @property
     def E2(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.t2`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorent2`."""
         raise AssertionError
 
     @property
     def e2(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.t2`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.t2`."""
         raise AssertionError
 
     @property
     def energy2(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.t2`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.t2`."""
         raise AssertionError
 
     @property
     def M(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.tau`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.tau`."""
         raise AssertionError
 
     @property
     def m(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.tau`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.tau`."""
         raise AssertionError
 
     @property
     def mass(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.tau`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.tau`."""
         raise AssertionError
 
     @property
     def M2(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.tau2`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.tau2`."""
         raise AssertionError
 
     @property
     def m2(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.tau2`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.tau2`."""
         raise AssertionError
 
     @property
     def mass2(self) -> ScalarCollection:
-        """
-        Momentum-synonym for :doc:`vector._methods.VectorProtocolLorentz.tau2`.
-        """
+        """Momentum-synonym for :attr:`vector._methods.VectorProtocolLorentz.tau2`."""
         raise AssertionError
 
     @property
@@ -1201,9 +1278,7 @@ class MomentumProtocolLorentz(VectorProtocolLorentz, MomentumProtocolSpatial):
 
     @property
     def transverse_energy(self) -> ScalarCollection:
-        """
-        Synonym for :doc:`vector._methods.MomentumProtocolLorentz.Et`.
-        """
+        """Synonym for :attr:`vector._methods.MomentumProtocolLorentz.Et`."""
         raise AssertionError
 
     @property
@@ -1224,9 +1299,7 @@ class MomentumProtocolLorentz(VectorProtocolLorentz, MomentumProtocolSpatial):
 
     @property
     def transverse_energy2(self) -> ScalarCollection:
-        """
-        Synonym for :doc:`vector._methods.MomentumProtocolLorentz.Et2`.
-        """
+        """Synonym for :attr:`vector._methods.MomentumProtocolLorentz.Et2`."""
         raise AssertionError
 
     @property
@@ -1247,9 +1320,7 @@ class MomentumProtocolLorentz(VectorProtocolLorentz, MomentumProtocolSpatial):
 
     @property
     def transverse_mass(self) -> ScalarCollection:
-        """
-        Synonym for :doc:`vector._methods.MomentumProtocolLorentz.Mt`.
-        """
+        """Synonym for :attr:`vector._methods.MomentumProtocolLorentz.Mt`."""
         raise AssertionError
 
     @property
@@ -1270,9 +1341,7 @@ class MomentumProtocolLorentz(VectorProtocolLorentz, MomentumProtocolSpatial):
 
     @property
     def transverse_mass2(self) -> ScalarCollection:
-        """
-        Synonym for :doc:`vector._methods.MomentumProtocolLorentz.Mt2`.
-        """
+        """Synonym for :attr:`vector._methods.MomentumProtocolLorentz.Mt2`."""
         raise AssertionError
 
 
@@ -1742,6 +1811,17 @@ class Planar(VectorProtocolPlanar):
         module = _compute_module_of(self, other)
         return module.subtract.dispatch(self, other)
 
+    @property
+    def neg2D(self: SameVectorType) -> SameVectorType:
+        from vector._compute.planar import scale
+
+        return scale.dispatch(-1, self)
+
+    def scale2D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
+        from vector._compute.planar import scale
+
+        return scale.dispatch(factor, self)
+
     def scale(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
         from vector._compute.planar import scale
 
@@ -1952,6 +2032,28 @@ class Spatial(Planar, VectorProtocolSpatial):
         module = _compute_module_of(self, other)
         return module.subtract.dispatch(self, other)
 
+    @property
+    def neg2D(self: SameVectorType) -> SameVectorType:
+        from vector._compute.planar import scale
+
+        return scale.dispatch(-1, self)
+
+    @property
+    def neg3D(self: SameVectorType) -> SameVectorType:
+        from vector._compute.spatial import scale
+
+        return scale.dispatch(-1, self)
+
+    def scale2D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
+        from vector._compute.planar import scale
+
+        return scale.dispatch(factor, self)
+
+    def scale3D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
+        from vector._compute.spatial import scale
+
+        return scale.dispatch(factor, self)
+
     def scale(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
         from vector._compute.spatial import scale
 
@@ -2034,6 +2136,16 @@ class Lorentz(Spatial, VectorProtocolLorentz):
 
         return rapidity.dispatch(self)
 
+    def deltaRapidityPhi(self, other: VectorProtocol) -> ScalarCollection:
+        from vector._compute.lorentz import deltaRapidityPhi
+
+        return deltaRapidityPhi.dispatch(self, other)
+
+    def deltaRapidityPhi2(self, other: VectorProtocol) -> ScalarCollection:
+        from vector._compute.lorentz import deltaRapidityPhi2
+
+        return deltaRapidityPhi2.dispatch(self, other)
+
     def boost_p4(self: SameVectorType, p4: VectorProtocolLorentz) -> SameVectorType:
         from vector._compute.lorentz import boost_p4
 
@@ -2059,6 +2171,33 @@ class Lorentz(Spatial, VectorProtocolLorentz):
                 "a Vector4D to boost by a momentum 4-vector"
             )
 
+    def boostCM_of_p4(
+        self: SameVectorType, p4: "VectorProtocolLorentz"
+    ) -> SameVectorType:
+        from vector._compute.lorentz import boost_p4
+
+        return boost_p4.dispatch(self, p4.neg3D)
+
+    def boostCM_of_beta3(
+        self: SameVectorType, beta3: "VectorProtocolSpatial"
+    ) -> SameVectorType:
+        from vector._compute.lorentz import boost_beta3
+
+        return boost_beta3.dispatch(self, beta3.neg3D)
+
+    def boostCM_of(self: SameVectorType, booster: "VectorProtocol") -> SameVectorType:
+        from vector._compute.lorentz import boost_beta3, boost_p4
+
+        if isinstance(booster, Vector3D):
+            return boost_beta3.dispatch(self, booster.neg3D)
+        elif isinstance(booster, Vector4D):
+            return boost_p4.dispatch(self, booster.neg3D)
+        else:
+            raise TypeError(
+                "specify a Vector3D to boost by beta (velocity with c=1) or "
+                "a Vector4D to boost by a momentum 4-vector"
+            )
+
     def boostX(
         self: SameVectorType,
         beta: typing.Optional[ScalarCollection] = None,
@@ -2143,6 +2282,39 @@ class Lorentz(Spatial, VectorProtocolLorentz):
         module = _compute_module_of(self, other)
         return module.subtract.dispatch(self, other)
 
+    @property
+    def neg2D(self: SameVectorType) -> SameVectorType:
+        from vector._compute.planar import scale
+
+        return scale.dispatch(-1, self)
+
+    @property
+    def neg3D(self: SameVectorType) -> SameVectorType:
+        from vector._compute.spatial import scale
+
+        return scale.dispatch(-1, self)
+
+    @property
+    def neg4D(self: SameVectorType) -> SameVectorType:
+        from vector._compute.lorentz import scale
+
+        return scale.dispatch(-1, self)
+
+    def scale2D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
+        from vector._compute.planar import scale
+
+        return scale.dispatch(factor, self)
+
+    def scale3D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
+        from vector._compute.spatial import scale
+
+        return scale.dispatch(factor, self)
+
+    def scale4D(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
+        from vector._compute.lorentz import scale
+
+        return scale.dispatch(factor, self)
+
     def scale(self: SameVectorType, factor: ScalarCollection) -> SameVectorType:
         from vector._compute.lorentz import scale
 
@@ -2337,9 +2509,7 @@ class LorentzMomentum(SpatialMomentum, MomentumProtocolLorentz):
 
 
 def dim(v: VectorProtocol) -> int:
-    """
-    Returns the number of dimensions in a vector: 2, 3, or 4.
-    """
+    """Returns the number of dimensions in a vector: 2, 3, or 4."""
     if isinstance(v, Vector2D):
         return 2
     elif isinstance(v, Vector3D):
@@ -2495,7 +2665,7 @@ def _lib_of(*objects: VectorProtocol) -> Module:  # NumPy-like module
     Determines the ``lib`` of a vector or set of vectors, complaining
     if they're incompatible.
     """
-    lib = None
+    lib: typing.Optional[typing.Any] = None
     for obj in objects:
         if isinstance(obj, Vector):
             if lib is None:
@@ -2527,12 +2697,22 @@ def _from_signature(
 
 
 _handler_priority = [
-    "vector._backends.object_",
-    "vector._backends.numpy_",
-    "vector._backends.awkward_",
+    "vector.backends.object",
+    "vector.backends.numpy",
+    "vector.backends.awkward",
 ]
 
 
+def _get_handler_index(obj: VectorProtocol) -> int:
+    """Returns the index of the first valid handler checking the list of parent classes"""
+    for cls in type(obj).__mro__:
+        with suppress(ValueError):
+            return _handler_priority.index(cls.__module__)
+    raise AssertionError(
+        f"Could not find a valid handler for {obj}! This should not happen."
+    )
+
+
 def _handler_of(*objects: VectorProtocol) -> VectorProtocol:
     """
     Determines which vector should wrap the output of a dispatched function.
@@ -2542,15 +2722,14 @@ def _handler_of(*objects: VectorProtocol) -> VectorProtocol:
     objects to NumPy arrays to Awkward Arrays whenever two are used in the
     same formula.
     """
-    handler = None
+    handler: typing.Optional[VectorProtocol] = None
     for obj in objects:
-        if isinstance(obj, Vector):
-            if handler is None:
-                handler = obj
-            elif _handler_priority.index(
-                type(obj).__module__
-            ) > _handler_priority.index(type(handler).__module__):
-                handler = obj
+        if not isinstance(obj, Vector):
+            continue
+        if handler is None:
+            handler = obj
+        elif _get_handler_index(obj) > _get_handler_index(handler):
+            handler = obj
 
     assert handler is not None
     return handler
@@ -2561,10 +2740,10 @@ def _flavor_of(*objects: VectorProtocol) -> typing.Type[VectorProtocol]:
     Determines the flavor of the output of a dispatched function, where
     "flavor" is generic vs momentum.
     """
-    from vector._backends.numpy_ import VectorNumpy
-    from vector._backends.object_ import VectorObject
+    from vector.backends.numpy import VectorNumpy
+    from vector.backends.object import VectorObject
 
-    handler = None
+    handler: typing.Optional[VectorProtocol] = None
     is_momentum = True
     for obj in objects:
         if isinstance(obj, Vector):
