@@ -3,18 +3,26 @@
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
 
+import os
+
 import pytest
 
 import vector
 
 ak = pytest.importorskip("awkward")
 numba = pytest.importorskip("numba")
-pytest.importorskip("vector._backends.numba_object")
+pytest.importorskip("vector.backends._numba_object")
 
 
 pytestmark = [pytest.mark.numba, pytest.mark.awkward]
 
 
+# awkward._v2 has not yet registered Numba dispatch mechanisms
+# see https://github.com/scikit-hep/awkward/discussions/1639
+# TODO: ensure this passes once awkward v2 is out
+@pytest.mark.xfail(
+    strict=True if os.environ.get("VECTOR_USE_AWKWARDV2") is not None else False
+)
 def test():
     @numba.njit
     def extract(x):
@@ -22,7 +30,7 @@ def test():
 
     array = vector.Array([[{"x": 1, "y": 2}], [], [{"x": 3, "y": 4}, {"x": 5, "y": 6}]])
     out = extract(array)
-    assert isinstance(out, vector._backends.object_.VectorObject2D)
+    assert isinstance(out, vector.backends.object.VectorObject2D)
     assert out.x == pytest.approx(3)
     assert out.y == pytest.approx(4)
 
@@ -30,7 +38,7 @@ def test():
         [[{"x": 1, "y": 2, "z": 3, "E": 4}], [], [{"x": 5, "y": 6, "z": 7, "E": 15}]]
     )
     out = extract(array)
-    assert isinstance(out, vector._backends.object_.MomentumObject4D)
+    assert isinstance(out, vector.backends.object.MomentumObject4D)
     assert out.x == pytest.approx(5)
     assert out.y == pytest.approx(6)
     assert out.z == pytest.approx(7)
