@@ -6,12 +6,12 @@
 import pytest
 
 import vector
-import vector._backends.object_
+import vector.backends.object
 
 numba = pytest.importorskip("numba")
 
 
-import vector._backends.numba_numpy  # noqa: E402
+import vector.backends.numba_numpy  # noqa: E402
 
 pytestmark = pytest.mark.numba
 
@@ -22,5 +22,5 @@ def test_pass_through():
         return obj
 
     array = vector.array({"px": [1, 2, 3], "py": [10, 20, 30]})
-    assert isinstance(array, vector._backends.numpy_.VectorNumpy)
-    assert isinstance(pass_through(array), vector._backends.numpy_.VectorNumpy)
+    assert isinstance(array, vector.backends.numpy.VectorNumpy)
+    assert isinstance(pass_through(array), vector.backends.numpy.VectorNumpy)
