@@ -5,15 +5,15 @@
 
 import pytest
 
-import vector._backends.numpy_
-import vector._backends.object_
+import vector.backends.numpy
+import vector.backends.object
 
 
 def test():
-    vec = vector._backends.object_.VectorObject4D(
-        vector._backends.object_.AzimuthalObjectXY(2, 3),
-        vector._backends.object_.LongitudinalObjectZ(1),
-        vector._backends.object_.TemporalObjectT(4),
+    vec = vector.backends.object.VectorObject4D(
+        vector.backends.object.AzimuthalObjectXY(2, 3),
+        vector.backends.object.LongitudinalObjectZ(1),
+        vector.backends.object.TemporalObjectT(4),
     )
     out = vec.boostY(gamma=-3)
     assert out.x == pytest.approx(2)
