@@ -6,21 +6,21 @@
 import numpy
 import pytest
 
-import vector._backends.numpy_
-import vector._backends.object_
+import vector.backends.numpy
+import vector.backends.object
 
 
 def test_xy():
-    vec = vector._backends.object_.VectorObject2D(
-        vector._backends.object_.AzimuthalObjectXY(1, 0)
+    vec = vector.backends.object.VectorObject2D(
+        vector.backends.object.AzimuthalObjectXY(1, 0)
     )
     assert vec.rotateZ(0.1).x == pytest.approx(0.9950041652780258)
     assert vec.rotateZ(0.1).y == pytest.approx(0.09983341664682815)
 
-    array = vector._backends.numpy_.VectorNumpy2D(
+    array = vector.backends.numpy.VectorNumpy2D(
         [(0, 0), (1, 0), (0, 1)], dtype=[("x", numpy.float64), ("y", numpy.float64)]
     )
-    assert isinstance(array.rotateZ(0.1), vector._backends.numpy_.VectorNumpy2D)
+    assert isinstance(array.rotateZ(0.1), vector.backends.numpy.VectorNumpy2D)
     out = array.rotateZ(0.1)
     assert out.dtype.names == ("x", "y")
     assert numpy.allclose(out.x, [0, 0.9950041652780258, -0.09983341664682815])
@@ -28,16 +28,16 @@ def test_xy():
 
 
 def test_rhophi():
-    vec = vector._backends.object_.VectorObject2D(
-        vector._backends.object_.AzimuthalObjectRhoPhi(1, 0)
+    vec = vector.backends.object.VectorObject2D(
+        vector.backends.object.AzimuthalObjectRhoPhi(1, 0)
     )
     assert vec.rotateZ(0.1).rho == pytest.approx(1)
     assert vec.rotateZ(0.1).phi == pytest.approx(0.1)
 
-    array = vector._backends.numpy_.VectorNumpy2D(
+    array = vector.backends.numpy.VectorNumpy2D(
         [(0, 0), (1, 0), (0, 1)], dtype=[("rho", numpy.float64), ("phi", numpy.float64)]
     )
-    assert isinstance(array.rotateZ(0.1), vector._backends.numpy_.VectorNumpy2D)
+    assert isinstance(array.rotateZ(0.1), vector.backends.numpy.VectorNumpy2D)
     out = array.rotateZ(0.1)
     assert out.dtype.names == ("rho", "phi")
     assert numpy.allclose(out.rho, [0, 1, 0])
