@@ -6,18 +6,18 @@
 import numpy
 import pytest
 
-import vector._backends.numpy_
-import vector._backends.object_
+import vector.backends.numpy
+import vector.backends.object
 
 
 def test_spatial_object():
-    v1 = vector._backends.object_.VectorObject3D(
-        vector._backends.object_.AzimuthalObjectXY(0.1, 0.2),
-        vector._backends.object_.LongitudinalObjectZ(0.3),
+    v1 = vector.backends.object.VectorObject3D(
+        vector.backends.object.AzimuthalObjectXY(0.1, 0.2),
+        vector.backends.object.LongitudinalObjectZ(0.3),
     )
-    v2 = vector._backends.object_.VectorObject3D(
-        vector._backends.object_.AzimuthalObjectXY(0.4, 0.5),
-        vector._backends.object_.LongitudinalObjectZ(0.6),
+    v2 = vector.backends.object.VectorObject3D(
+        vector.backends.object.AzimuthalObjectXY(0.4, 0.5),
+        vector.backends.object.LongitudinalObjectZ(0.6),
     )
     assert v1.deltaR2(v2) == pytest.approx(0.116083865330319)
 
@@ -33,11 +33,11 @@ def test_spatial_object():
 
 
 def test_spatial_numpy():
-    v1 = vector._backends.numpy_.VectorNumpy3D(
+    v1 = vector.backends.numpy.VectorNumpy3D(
         [(0.1, 0.2, 0.3)],
         dtype=[("x", numpy.float64), ("y", numpy.float64), ("z", numpy.float64)],
     )
-    v2 = vector._backends.numpy_.VectorNumpy3D(
+    v2 = vector.backends.numpy.VectorNumpy3D(
         [(0.4, 0.5, 0.6)],
         dtype=[("x", numpy.float64), ("y", numpy.float64), ("z", numpy.float64)],
     )
@@ -53,15 +53,15 @@ def test_spatial_numpy():
 
 
 def test_lorentz_object():
-    v1 = vector._backends.object_.VectorObject4D(
-        vector._backends.object_.AzimuthalObjectXY(0.1, 0.2),
-        vector._backends.object_.LongitudinalObjectZ(0.3),
-        vector._backends.object_.TemporalObjectT(99),
+    v1 = vector.backends.object.VectorObject4D(
+        vector.backends.object.AzimuthalObjectXY(0.1, 0.2),
+        vector.backends.object.LongitudinalObjectZ(0.3),
+        vector.backends.object.TemporalObjectT(99),
     )
-    v2 = vector._backends.object_.VectorObject4D(
-        vector._backends.object_.AzimuthalObjectXY(0.4, 0.5),
-        vector._backends.object_.LongitudinalObjectZ(0.6),
-        vector._backends.object_.TemporalObjectT(99),
+    v2 = vector.backends.object.VectorObject4D(
+        vector.backends.object.AzimuthalObjectXY(0.4, 0.5),
+        vector.backends.object.LongitudinalObjectZ(0.6),
+        vector.backends.object.TemporalObjectT(99),
     )
     assert v1.deltaR2(v2) == pytest.approx(0.116083865330319)
 
@@ -98,7 +98,7 @@ def test_lorentz_object():
 
 
 def test_lorentz_numpy():
-    v1 = vector._backends.numpy_.VectorNumpy4D(
+    v1 = vector.backends.numpy.VectorNumpy4D(
         [(0.1, 0.2, 0.3, 99)],
         dtype=[
             ("x", numpy.float64),
@@ -107,7 +107,7 @@ def test_lorentz_numpy():
             ("t", numpy.float64),
         ],
     )
-    v2 = vector._backends.numpy_.VectorNumpy4D(
+    v2 = vector.backends.numpy.VectorNumpy4D(
         [(0.4, 0.5, 0.6, 99)],
         dtype=[
             ("x", numpy.float64),
