@@ -5,16 +5,16 @@
 
 import numpy
 
-import vector._backends.numpy_
-import vector._backends.object_
+import vector.backends.numpy
+import vector.backends.object
 
 
 def test_planar_object():
-    v1 = vector._backends.object_.VectorObject2D(
-        vector._backends.object_.AzimuthalObjectXY(0.1, 0.2)
+    v1 = vector.backends.object.VectorObject2D(
+        vector.backends.object.AzimuthalObjectXY(0.1, 0.2)
     )
-    v2 = vector._backends.object_.VectorObject2D(
-        vector._backends.object_.AzimuthalObjectXY(0.1, 0.2)
+    v2 = vector.backends.object.VectorObject2D(
+        vector.backends.object.AzimuthalObjectXY(0.1, 0.2)
     )
     assert v1.equal(v2)
 
@@ -29,11 +29,11 @@ def test_planar_object():
 
 
 def test_planar_numpy():
-    v1 = vector._backends.numpy_.VectorNumpy2D(
+    v1 = vector.backends.numpy.VectorNumpy2D(
         [(0.1, 0.2)],
         dtype=[("x", numpy.float64), ("y", numpy.float64)],
     )
-    v2 = vector._backends.numpy_.VectorNumpy2D(
+    v2 = vector.backends.numpy.VectorNumpy2D(
         [(0.1, 0.2)],
         dtype=[("x", numpy.float64), ("y", numpy.float64)],
     )
@@ -50,13 +50,13 @@ def test_planar_numpy():
 
 
 def test_spatial_object():
-    v1 = vector._backends.object_.VectorObject3D(
-        vector._backends.object_.AzimuthalObjectXY(0.1, 0.2),
-        vector._backends.object_.LongitudinalObjectZ(0.3),
+    v1 = vector.backends.object.VectorObject3D(
+        vector.backends.object.AzimuthalObjectXY(0.1, 0.2),
+        vector.backends.object.LongitudinalObjectZ(0.3),
     )
-    v2 = vector._backends.object_.VectorObject3D(
-        vector._backends.object_.AzimuthalObjectXY(0.1, 0.2),
-        vector._backends.object_.LongitudinalObjectZ(0.3),
+    v2 = vector.backends.object.VectorObject3D(
+        vector.backends.object.AzimuthalObjectXY(0.1, 0.2),
+        vector.backends.object.LongitudinalObjectZ(0.3),
     )
     assert v1.equal(v2)
 
@@ -71,11 +71,11 @@ def test_spatial_object():
 
 
 def test_spatial_numpy():
-    v1 = vector._backends.numpy_.VectorNumpy3D(
+    v1 = vector.backends.numpy.VectorNumpy3D(
         [(0.1, 0.2, 0.3)],
         dtype=[("x", numpy.float64), ("y", numpy.float64), ("z", numpy.float64)],
     )
-    v2 = vector._backends.numpy_.VectorNumpy3D(
+    v2 = vector.backends.numpy.VectorNumpy3D(
         [(0.1, 0.2, 0.3)],
         dtype=[("x", numpy.float64), ("y", numpy.float64), ("z", numpy.float64)],
     )
@@ -92,15 +92,15 @@ def test_spatial_numpy():
 
 
 def test_lorentz_object():
-    v1 = vector._backends.object_.VectorObject4D(
-        vector._backends.object_.AzimuthalObjectXY(0.1, 0.2),
-        vector._backends.object_.LongitudinalObjectZ(0.3),
-        vector._backends.object_.TemporalObjectT(0.4),
+    v1 = vector.backends.object.VectorObject4D(
+        vector.backends.object.AzimuthalObjectXY(0.1, 0.2),
+        vector.backends.object.LongitudinalObjectZ(0.3),
+        vector.backends.object.TemporalObjectT(0.4),
     )
-    v2 = vector._backends.object_.VectorObject4D(
-        vector._backends.object_.AzimuthalObjectXY(0.1, 0.2),
-        vector._backends.object_.LongitudinalObjectZ(0.3),
-        vector._backends.object_.TemporalObjectT(0.4),
+    v2 = vector.backends.object.VectorObject4D(
+        vector.backends.object.AzimuthalObjectXY(0.1, 0.2),
+        vector.backends.object.LongitudinalObjectZ(0.3),
+        vector.backends.object.TemporalObjectT(0.4),
     )
     assert v1.equal(v2)
 
@@ -138,7 +138,7 @@ def test_lorentz_object():
 
 
 def test_lorentz_numpy():
-    v1 = vector._backends.numpy_.VectorNumpy4D(
+    v1 = vector.backends.numpy.VectorNumpy4D(
         [(0.1, 0.2, 0.3, 0.4)],
         dtype=[
             ("x", numpy.float64),
@@ -147,7 +147,7 @@ def test_lorentz_numpy():
             ("t", numpy.float64),
         ],
     )
-    v2 = vector._backends.numpy_.VectorNumpy4D(
+    v2 = vector.backends.numpy.VectorNumpy4D(
         [(0.1, 0.2, 0.3, 0.4)],
         dtype=[
             ("x", numpy.float64),
