@@ -6,16 +6,16 @@
 import numpy
 import pytest
 
-import vector._backends.numpy_
-import vector._backends.object_
+import vector.backends.numpy
+import vector.backends.object
 
 
 def test_planar_object():
-    v1 = vector._backends.object_.VectorObject2D(
-        vector._backends.object_.AzimuthalObjectXY(3, 4)
+    v1 = vector.backends.object.VectorObject2D(
+        vector.backends.object.AzimuthalObjectXY(3, 4)
     )
-    v2 = vector._backends.object_.VectorObject2D(
-        vector._backends.object_.AzimuthalObjectXY(5, 12)
+    v2 = vector.backends.object.VectorObject2D(
+        vector.backends.object.AzimuthalObjectXY(5, 12)
     )
     out = v1.subtract(v2)
     assert out.x == pytest.approx(-2)
@@ -33,11 +33,11 @@ def test_planar_object():
 
 
 def test_planar_numpy():
-    v1 = vector._backends.numpy_.VectorNumpy2D(
+    v1 = vector.backends.numpy.VectorNumpy2D(
         [(3, 4)],
         dtype=[("x", numpy.float64), ("y", numpy.float64)],
     )
-    v2 = vector._backends.numpy_.VectorNumpy2D(
+    v2 = vector.backends.numpy.VectorNumpy2D(
         [(5, 12)],
         dtype=[("x", numpy.float64), ("y", numpy.float64)],
     )
@@ -57,13 +57,13 @@ def test_planar_numpy():
 
 
 def test_spatial_object():
-    v1 = vector._backends.object_.VectorObject3D(
-        vector._backends.object_.AzimuthalObjectXY(3, 4),
-        vector._backends.object_.LongitudinalObjectZ(2),
+    v1 = vector.backends.object.VectorObject3D(
+        vector.backends.object.AzimuthalObjectXY(3, 4),
+        vector.backends.object.LongitudinalObjectZ(2),
     )
-    v2 = vector._backends.object_.VectorObject3D(
-        vector._backends.object_.AzimuthalObjectXY(5, 12),
-        vector._backends.object_.LongitudinalObjectZ(4),
+    v2 = vector.backends.object.VectorObject3D(
+        vector.backends.object.AzimuthalObjectXY(5, 12),
+        vector.backends.object.LongitudinalObjectZ(4),
     )
     out = v1.subtract(v2)
     assert out.x == pytest.approx(-2)
@@ -83,11 +83,11 @@ def test_spatial_object():
 
 
 def test_spatial_numpy():
-    v1 = vector._backends.numpy_.VectorNumpy3D(
+    v1 = vector.backends.numpy.VectorNumpy3D(
         [(3, 4, 2)],
         dtype=[("x", numpy.float64), ("y", numpy.float64), ("z", numpy.float64)],
     )
-    v2 = vector._backends.numpy_.VectorNumpy3D(
+    v2 = vector.backends.numpy.VectorNumpy3D(
         [(5, 12, 4)],
         dtype=[("x", numpy.float64), ("y", numpy.float64), ("z", numpy.float64)],
     )
@@ -109,15 +109,15 @@ def test_spatial_numpy():
 
 
 def test_lorentz_object():
-    v1 = vector._backends.object_.VectorObject4D(
-        vector._backends.object_.AzimuthalObjectXY(3, 4),
-        vector._backends.object_.LongitudinalObjectZ(2),
-        vector._backends.object_.TemporalObjectT(20),
+    v1 = vector.backends.object.VectorObject4D(
+        vector.backends.object.AzimuthalObjectXY(3, 4),
+        vector.backends.object.LongitudinalObjectZ(2),
+        vector.backends.object.TemporalObjectT(20),
     )
-    v2 = vector._backends.object_.VectorObject4D(
-        vector._backends.object_.AzimuthalObjectXY(5, 12),
-        vector._backends.object_.LongitudinalObjectZ(4),
-        vector._backends.object_.TemporalObjectT(15),
+    v2 = vector.backends.object.VectorObject4D(
+        vector.backends.object.AzimuthalObjectXY(5, 12),
+        vector.backends.object.LongitudinalObjectZ(4),
+        vector.backends.object.TemporalObjectT(15),
     )
     out = v1.subtract(v2)
     assert out.x == pytest.approx(-2)
@@ -165,7 +165,7 @@ def test_lorentz_object():
 
 
 def test_lorentz_numpy():
-    v1 = vector._backends.numpy_.VectorNumpy4D(
+    v1 = vector.backends.numpy.VectorNumpy4D(
         [(3, 4, 2, 20)],
         dtype=[
             ("x", numpy.float64),
@@ -174,7 +174,7 @@ def test_lorentz_numpy():
             ("t", numpy.float64),
         ],
     )
-    v2 = vector._backends.numpy_.VectorNumpy4D(
+    v2 = vector.backends.numpy.VectorNumpy4D(
         [(5, 12, 4, 15)],
         dtype=[
             ("x", numpy.float64),
